"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchQueryBuilderOperatorAndInPlugin = void 0;
var _ElasticsearchQueryBuilderOperatorPlugin = require("../definition/ElasticsearchQueryBuilderOperatorPlugin");
class ElasticsearchQueryBuilderOperatorAndInPlugin extends _ElasticsearchQueryBuilderOperatorPlugin.ElasticsearchQueryBuilderOperatorPlugin {
  name = "elasticsearch.queryBuilder.operator.andIn.default";
  getOperator() {
    return "and_in";
  }
  apply(query, params) {
    const {
      value: values,
      path,
      basePath
    } = params;
    const isArray = Array.isArray(values);
    if (isArray === false || values.length === 0) {
      throw new Error(`You cannot filter field "${path}" with "in" operator and not send an array of values.`);
    }
    let useBasePath = false;
    // Only use ".keyword" if all of the provided values are strings.
    for (const value of values) {
      if (typeof value !== "string") {
        useBasePath = true;
        break;
      }
    }
    for (const value of values) {
      query.filter.push({
        term: {
          [useBasePath ? basePath : path]: value
        }
      });
    }
  }
}
exports.ElasticsearchQueryBuilderOperatorAndInPlugin = ElasticsearchQueryBuilderOperatorAndInPlugin;

//# sourceMappingURL=andIn.js.map